ToPrefixedLabel

Trait ToPrefixedLabel 

pub trait ToPrefixedLabel: Display {
    // Provided method
    fn to_prefixed_string(&self, protocol_version: ProtocolVersion) -> String { ... }
}
This trait allows implementers to automatically get a MLS-specific representation that takes in account protocol versions and the label format.

For example, the MLS 1.0 format is MLS 1.0 {label}.

Provided Methods

fn to_prefixed_string(&self, protocol_version: ProtocolVersion) -> String

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors